==> relic-tool-chunky-core-1.0.1.tar.gz: relic-tool-chunky-core-1.0.1/README.md <==
# Relic Tool - Chunky - Core
[![PyPI](https://img.shields.io/pypi/v/relic-tool-chunky-core)](https://pypi.org/project/Relic-Tool-Chunky-Core/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/relic-tool-chunky-core)](https://www.python.org/downloads/)
[![PyPI - License](https://img.shields.io/pypi/l/relic-tool-chunky-core)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/blob/main/LICENSE.txt)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/PyCQA/pylint)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Pytest](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pytest.yml/badge.svg)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pytest.yml)
[![Pylint](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pylint.yml/badge.svg)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pylint.yml)
[![MyPy](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/mypy.yml/badge.svg)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/mypy.yml)
#### Disclaimer
Not affiliated with Sega, Relic Entertainment, or THQ.
#### Description
Core files used to read/write Relic Chunky files.

## Installation (Pip)
### Installing from PyPI (Recommended)
```
pip install relic-tool-chunky-core
```
### Installing from GitHub
For more information, see [pip VCS support](https://pip.pypa.io/en/stable/topics/vcs-support/#git)
```
pip install git+https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core
```

==> relic-tool-chunky-core-1.1.0.tar.gz: relic-tool-chunky-core-1.1.0/README.md <==
# Relic Tool - Chunky - Core
[![PyPI](https://img.shields.io/pypi/v/relic-tool-chunky-core)](https://pypi.org/project/Relic-Tool-Chunky-Core/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/relic-tool-chunky-core)](https://www.python.org/downloads/)
[![PyPI - License](https://img.shields.io/pypi/l/relic-tool-chunky-core)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/blob/main/LICENSE.txt)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/PyCQA/pylint)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Pytest](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pytest.yml/badge.svg)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pytest.yml)
[![Pylint](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pylint.yml/badge.svg)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/pylint.yml)
[![MyPy](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/mypy.yml/badge.svg)](https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core/actions/workflows/mypy.yml)
[![GitHub issues by-label](https://img.shields.io/github/issues/MAK-Relic-Tool/Issue-Tracker/Chunky)](https://github.com/MAK-Relic-Tool/Issue-Tracker/issues?q=is%3Aissue+is%3Aopen+label%3AChunky)
#### Disclaimer
Not affiliated with Sega, Relic Entertainment, or THQ.

#### Description
Core files used to read/write Relic Chunky files.

## Installation (Pip)
### Installing from PyPI (Recommended)
```
pip install relic-tool-chunky-core
```
### Installing from GitHub
For more information, see [pip VCS support](https://pip.pypa.io/en/stable/topics/vcs-support/#git)
```
pip install git+https://github.com/MAK-Relic-Tool/Relic-Tool-Chunky-Core
```

## Report A Bug / Issue
Visit the [Issue Tracker](https://github.com/MAK-Relic-Tool/Issue-Tracker/issues)
